@@ -2,6 +2,7 @@
 package domeneshop
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"net/http"
@@ -100,12 +101,14 @@ func (d *DNSProvider) Present(domain, _, keyAuth string) error {
 		return fmt.Errorf("domeneshop: %w", err)
 	}
 
-	domainInstance, err := d.client.GetDomainByName(zone)
+	ctx := context.Background()
+
+	domainInstance, err := d.client.GetDomainByName(ctx, zone)
 	if err != nil {
 		return fmt.Errorf("domeneshop: %w", err)
 	}
 
-	err = d.client.CreateTXTRecord(domainInstance, host, info.Value)
+	err = d.client.CreateTXTRecord(ctx, domainInstance, host, info.Value)
 	if err != nil {
 		return fmt.Errorf("domeneshop: failed to create record: %w", err)
 	}
@@ -122,12 +125,14 @@ func (d *DNSProvider) CleanUp(domain, _, keyAuth string) error {
 		return fmt.Errorf("domeneshop: %w", err)
 	}
 
-	domainInstance, err := d.client.GetDomainByName(zone)
+	ctx := context.Background()
+
+	domainInstance, err := d.client.GetDomainByName(ctx, zone)
 	if err != nil {
 		return fmt.Errorf("domeneshop: %w", err)
 	}
 
-	if err := d.client.DeleteTXTRecord(domainInstance, host, info.Value); err != nil {
+	if err := d.client.DeleteTXTRecord(ctx, domainInstance, host, info.Value); err != nil {
 		return fmt.Errorf("domeneshop: failed to create record: %w", err)
 	}
 
@@ -138,7 +143,7 @@ func (d *DNSProvider) CleanUp(domain, _, keyAuth string) error {
 func (d *DNSProvider) splitDomain(fqdn string) (string, string, error) {
 	zone, err := dns01.FindZoneByFqdn(fqdn)
 	if err != nil {
-		return "", "", err
+		return "", "", fmt.Errorf("could not find zone for FQDN %q: %w", fqdn, err)
 	}
 
 	subDomain, err := dns01.ExtractSubDomain(fqdn, zone)
